@@ -51,7 +51,7 @@ unless ( $G{file} || $G{scan} ) {
     pod2usage( -exitstatus => 0, -verbose => 2 );
 }
 
-print "\nnmap2sqlite.pl - ( http://nmapparser.wordpress.com )\n",
+print "\nnmap2sqlite.pl - ( http://anthonypersaud.com )\n",
   ( '-' x 50 ), "\n\n";
 
 if ( $G{scan} && $G{nmap} eq '' ) {
@@ -308,25 +308,36 @@ L<http://code.google.com/p/nmap-parser/issues/list>
 
 L<Nmap::Parser>
 
-The Nmap::Parser page can be found at: L<http://nmapparser.wordpress.com> or L<http://npx.sourceforge.net>.
+The Nmap::Parser page can be found at: L<http://anthonypersaud.com/category/nmap-parser/>.
 It contains the latest developments on the module. The nmap security scanner
 homepage can be found at: L<http://www.insecure.org/nmap/>.
 
 =head1 AUTHOR
 
-Anthony G Persaud <apersaud[at]gmail.com> L<http://www.anthonypersaud.com>
+Anthony G Persaud L<http://anthonypersaud.com>
 
 =head1 COPYRIGHT
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free Software
-Foundation; either version 2 of the License, or (at your option) any later
-version.
+Copyright (c) <2003-2009> <Anthony G. Persaud>
 
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+MIT License
 
-L<http://www.opensource.org/licenses/gpl-license.php>
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 
 =cut
